tidy_model_parameters: Convert '{parameters}' package output to '{tidyverse}'...

View source: R/helpers-easystats.R

tidy_model_parametersR Documentation

Convert {parameters} package output to {tidyverse} conventions

Description

Runs parameters::model_parameters() on a model object and standardizes the result to {broom}-style column names (e.g. estimate, std.error, conf.low, conf.high, statistic, df.error, p.value). Bayes factors are returned in a bf10 column, along with their natural logarithm in log_e_bf10. For Bayesian ANOVA designs ({BayesFactor} linear models), the estimate is replaced by the Bayesian R-squared.

Usage

tidy_model_parameters(model, ...)

Arguments

model

Statistical Model.

...

Arguments passed to or from other methods. Non-documented arguments are

  • digits, p_digits, ci_digits and footer_digits to set the number of digits for the output. groups can be used to group coefficients. These arguments will be passed to the print-method, or can directly be used in print(), see documentation in print.parameters_model().

  • If s_value = TRUE, the p-value will be replaced by the S-value in the output (cf. Rafi and Greenland 2020).

  • pd adds an additional column with the probability of direction (see bayestestR::p_direction() for details). Furthermore, see 'Examples' in model_parameters.default().

  • For developers, whose interest mainly is to get a "tidy" data frame of model summaries, it is recommended to set pretty_names = FALSE to speed up computation of the summary table.

Value

A tibble with one row per parameter.

Citation

Patil, I., (2021). statsExpressions: R Package for Tidy Dataframes and Expressions with Statistical Details. Journal of Open Source Software, 6(61), 3236, https://doi.org/10.21105/joss.03236

Examples

model <- lm(mpg ~ wt + cyl, data = mtcars)
tidy_model_parameters(model)


statsExpressions documentation built on Oct. 9, 2026, 5:06 p.m.