View source: R/pairwise-contingency-table.R
| pairwise_contingency_table | R Documentation |
Pairwise Fisher's exact tests as post hoc tests for contingency table analyses, with effect sizes (Cramer's V) and p-value adjustment for multiple comparisons.
pairwise_contingency_table(
data,
x,
y,
counts = NULL,
p.adjust.method = "holm",
digits = 2L,
conf.level = 0.95,
alternative = "two.sided",
...
)
data |
A data frame (or a tibble) from which variables specified are to
be taken. Other data types (e.g., matrix,table, array, etc.) will not
be accepted. Additionally, grouped data frames from |
x |
The variable to use as the rows in the contingency table. |
y |
The variable to use as the columns in the contingency table.
Default is |
counts |
The variable in data containing counts, or |
p.adjust.method |
Adjustment method for p-values for multiple
comparisons. Possible methods are: |
digits |
Number of digits for rounding or significant figures. May also
be |
conf.level |
Scalar between |
alternative |
A character string specifying the alternative hypothesis;
Controls the type of CI returned: |
... |
Additional arguments (currently ignored). |
The returned tibble data frame can contain some or all of the following columns (the exact columns will depend on the statistical test):
statistic: the numeric value of a statistic
df: the numeric value of a parameter being modeled (often degrees
of freedom for the test)
df.error and df: relevant only if the statistic in question has
two degrees of freedom (e.g. anova)
p.value: the two-sided p-value associated with the observed statistic
method: the name of the inferential statistical test
estimate: estimated value of the effect size
conf.low: lower bound for the effect size estimate
conf.high: upper bound for the effect size estimate
conf.level: width of the confidence interval
conf.method: method used to compute confidence interval
conf.distribution: statistical distribution for the effect
effectsize: the name of the effect size
n.obs: number of observations
expression: pre-formatted expression containing statistical details
For examples, see data frame output vignette.
The table below provides summary about:
statistical test carried out for inferential statistics
type of effect size estimate and a measure of uncertainty for this estimate
functions used internally to compute these details
Hypothesis testing
| Test | p-value adjustment? | Function used |
| Fisher's exact test | Yes | stats::fisher.test() |
Effect size estimation
| Effect size | CI available? | Function used |
| Cramer's V | Yes | effectsize::cramers_v() |
Patil, I., (2021). statsExpressions: R Package for Tidy Dataframes and Expressions with Statistical Details. Journal of Open Source Software, 6(61), 3236, https://doi.org/10.21105/joss.03236
# for reproducibility
set.seed(123)
library(statsExpressions)
# pairwise Fisher's exact tests with Holm adjustment
pairwise_contingency_table(
data = mtcars,
x = cyl,
y = am,
p.adjust.method = "holm"
)
# with counts data and Bonferroni adjustment
pairwise_contingency_table(
data = as.data.frame(Titanic),
x = Class,
y = Survived,
counts = Freq,
p.adjust.method = "bonferroni"
)
# no p-value adjustment
pairwise_contingency_table(
data = mtcars,
x = cyl,
y = am,
p.adjust.method = "none"
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.