- data
A data frame (or a tibble) from which variables specified are to
be taken. Other data types (e.g., matrix,table, array, etc.) will not
be accepted. Additionally, grouped data frames from {dplyr} should be
ungrouped before they are entered as data.
- x
The variable to use as the rows in the contingency table.
- y
The variable to use as the columns in the contingency table.
Default is NULL. If NULL, one-sample proportion test (a goodness of fit
test) will be run for the x variable.
- counts
The variable in data containing counts, or NULL if each row
represents a single observation.
- p.adjust.method
Adjustment method for p-values for multiple
comparisons. Possible methods are: "holm" (default), "hochberg",
"hommel", "bonferroni", "BH", "BY", "fdr", "none".
- digits
Number of digits for rounding or significant figures. May also
be "signif" to return significant figures or "scientific"
to return scientific notation. Control the number of digits by adding the
value as suffix, e.g. digits = "scientific4" to have scientific
notation with 4 decimal places, or digits = "signif5" for 5
significant figures (see also signif()).
- conf.level
Scalar between 0 and 1 (default: 95%
confidence/credible intervals, 0.95). If NULL, no confidence intervals
will be computed.
- alternative
A character string specifying the alternative hypothesis;
Controls the type of CI returned: "two.sided" (default, two-sided CI),
"greater" or "less" (one-sided CI). Partial matching is allowed
(e.g., "g", "l", "two"...). See section One-Sided CIs in
the effectsize_CIs vignette.
- ...
Additional arguments (currently ignored).